@@ -24,7 +24,7 @@ extras_require = {}
 install_requires = [
     "lazy_object_proxy==1.4.*",
     "six",
-    "wrapt==1.11.*",
+    "wrapt",
     'typed-ast>=1.4.0,<1.5;implementation_name== "cpython" and python_version<"3.8"',
 ]
 
